pub struct FlatTokenDecoder { /* private fields */ }Expand description
Experimental token decoding with a one-dimensional approach, working directly on a flat representation of
the model output, with one padding by dimension to access appropriate value. Not very readable, but might
be interresting from a performance standpoint. To be benchmarked, and checked for accurracy according to
the original implementation. In the meantime, prefer the token.rs which performs the same operation in
a much more readable way, basing on the four-dimensional output tensor.