pub struct RelationFormatError { /* private fields */ }Expand description
Defines an error caused by an malformed or unexpected span label obtained from the relation extraction pipeline. This is likely to be an internal error, unless the pipeline was not used correctly.
Implementations
Sourceimpl RelationFormatError
impl RelationFormatError
pub fn invalid_relation_label(label: &str) -> Self
pub fn unexpected_relation_label(label: &str) -> Self
pub fn err<T>(self) -> Result<T>