Parameters

Struct Parameters 

pub struct Parameters {
    pub threshold: f32,
    pub flat_ner: bool,
    pub dup_label: bool,
    pub multi_label: bool,
    pub max_width: usize,
    pub max_length: Option<usize>,
}
Represents the set of parameters for the whole pipeline

  • pre-processing
  • post-processing

The easiest way to instanciate sound parameters is to use the default() constructor and then use individual setters as needed.

Fields

threshold: f32

Probability threshold (default: 0.5)

flat_ner: bool

Setting this parameter to true means that no entity can overlap with another one (default: true)

dup_label: bool

If flat_ner=false, setting this parameter to true means that overlapping spans can belong to the same class (default: false)

multi_label: bool

If flat_ner=false, setting this parameter to true means that overlapping spans can belong to different classes (default: false)

max_width: usize

For span mode, maximum span width (default: 12)

max_length: Option<usize>

Maximum sequence length (default: 512)

Implementations

Source

impl Parameters

pub fn new( threshold: f32, max_width: usize, max_length: Option<usize>, flat_ner: bool, dup_label: bool, multi_label: bool, ) -> Self

New configuration specifying every parameter

pub fn with_threshold(self, threshold: f32) -> Self

pub fn with_max_width(self, max_width: usize) -> Self

pub fn with_max_length(self, max_length: Option<usize>) -> Self

pub fn with_flat_ner(self, flat_ner: bool) -> Self

pub fn with_dup_label(self, dup_label: bool) -> Self

pub fn with_multi_label(self, multi_label: bool) -> Self