pub struct IndexError { /* private fields */ }Expand description
Defines an error caused by the use of an incorrect index in one of the structures exchanged during a pipeline. This is an internal error that only occurs if there is a bug in the algorithms ensuring the consistency of this data, and it cannot be recovered from except by abandoning the ongoing process and report an error. However, it is preferred over panicking to ensure safe usage of the library (please document an issue in this case, providing the message available in this struct).
Implementations